"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateSelector = void 0;
const childNodeIndexOf = (parentNode, childNode) => Array.prototype.indexOf.call(parentNode.childNodes, childNode);
const computedNthIndex = (childElement) => {
    let elementsWithSameTag = 0;
    const parent = childElement.parentElement;
    if (parent) {
        // eslint-disable-next-line no-restricted-syntax
        for (const currentChild of parent.children) {
            if (currentChild.tagName === childElement.tagName) {
                elementsWithSameTag++;
            }
            if (currentChild === childElement) {
                break;
            }
        }
    }
    return elementsWithSameTag;
};
const generateSelector = (node, relativeTo) => {
    const tagNames = [];
    let currentNode = node;
    const textNodeIndex = node.parentNode ? childNodeIndexOf(node.parentNode, node) : 0;
    while (currentNode && currentNode !== relativeTo.parentElement) {
        const tagName = currentNode.tagName?.toLowerCase();
        if (tagName) {
            const nthIndex = computedNthIndex(currentNode);
            tagNames.push(nthIndex > 1 ? `${tagName}:nth-of-type(${nthIndex})` : tagName);
        }
        currentNode = currentNode.parentElement;
    }
    return {
        s: tagNames.reverse().join('>'),
        c: textNodeIndex,
        o: 0,
    };
};
exports.generateSelector = generateSelector;
